/*
Copyright 2017 Mikael Berthe

Licensed under the MIT license.  Please see the LICENSE file is this directory.
*/

package madon

import (
	"github.com/sendgrid/rest"
)

// GetFavourites returns the list of the user's favourites
// If lopt.All is true, several requests will be made until the API server
// has nothing to return.
// If lopt.Limit is set (and not All), several queries can be made until the
// limit is reached.
func (mc *Client) GetFavourites(lopt *LimitParams) ([]Status, error) {
	var faves []Status
	var links apiLinks
	err := mc.apiCall("favourites", rest.Get, nil, lopt, &links, &faves)
	if err != nil {
		return nil, err
	}
	if lopt != nil { // Fetch more pages to reach our limit
		var faveSlice []Status
		for (lopt.All || lopt.Limit > len(faves)) && links.next != nil {
			newlopt := links.next
			links = apiLinks{}
			if err := mc.apiCall("favourites", rest.Get, nil, newlopt, &links, &faveSlice); err != nil {
				return nil, err
			}
			faves = append(faves, faveSlice...)
			faveSlice = faveSlice[:0] // Clear struct
		}
	}
	return faves, nil
}
